import React from 'react';
import './TuyaButton.scss';

interface ButtonProps {
  /**
   * is the button primary?
   */
  primary?: boolean;
  /**
   * How large should the button be?
   */
  size?: 'small' | 'medium' | 'large';
  /**
   * Button label
   */
  label: string;
   /**
   * Button disable
  */
  disabled?: boolean;
  /**
   * button vertical boolean
   */
  vertical?: boolean;
   /**
    * Vertical button shape
    */
  shape?: 'square' | 'circle';
   /**
    * Optional click handler
    */
  onClick?: () => void;
}

/**
 * Primary UI component for user interaction
 */
export const TuyaButton = ({
  primary = false,
  size = 'medium',
  label,
  disabled = false,
  vertical = false,
  shape = 'square',
  ...props
}: ButtonProps) => {
  return (
    !vertical ? 
    (<button
      type="button"
      className={`
        tuya-button text-ellipsis overflow-hidden
        tuya-button--${size}
        ${primary ? 'tuya-button--primary' : 'tuya-button--secondary'}
        ${disabled ? 'cursor-not-allowed opacity-50': ''} 
      `}
      disabled={disabled}
    >
      {label}
    </button>)
    : (
    <button
      type="button"
      className={`
        tuya-vertical-button
        bg-tuya-gray
        flex flex-col text-center justify-center align-middle items-center
        ${shape === 'circle' ? 'rounded-full' : 'rounded-lg'}
        ${disabled ? 'cursor-not-allowed opacity-50': ''}   
      `}
      disabled={disabled}
    >
      <span className='text-sm'>ICON</span>
      <span className='px-3 py-1 text-sm text-black text-ellipsis overflow-hidden '>{label}</span>
    </button>
    )
  );
};
