import React from "react";
import { TouchableOpacity, View, Text, StyleSheet } from "react-native";
import tailwind from "tailwind-rn";
import LinearGradient from "react-native-web-linear-gradient";
import stylesSCSS from '../../../styles/style.module.scss';
import { generateIconComponent } from "../../../shared/services";

interface TuyaCheckBoxProps {
  /**
   * Button contents
   */
  label: string;
  selected: boolean;
  /**
   * Button disable
   */
  disabled?: boolean;
  /**
   * button vertical boolean
   */
  /**
   * How large should the button be?
   */
  size?: "default" | "big";
  onClick?: (currentSelected: boolean) => void;
}
let checkIconComponent = generateIconComponent('IconDoneWhite22Px');

export const TuyaCheckBox: React.FC<TuyaCheckBoxProps> = ({
  label,
  size = "default",
  selected = false,
  disabled = false,
  ...props
}: TuyaCheckBoxProps) => {
  const styles = StyleSheet.create({
    container: {
      height: 32,
      width: 145,
    },
  });
  return (
    <View style={styles.container} className={`flex flex-row items-center m-0 p-0 ${disabled ? " cursor-not-allowed opacity-50" : "opacity-100"}`} >
      <TouchableOpacity
        className="shadow-inset-tuya w-8 h-8 rounded-lg border-2 bg-transparent border-transparent items-center justify-center "
        disabled={disabled}
        onPress={() => {
          props.onClick && props.onClick(!selected)
        }}
      >
        {selected ? (
          <LinearGradient
            colors={[stylesSCSS.CTAtuyaColor1,stylesSCSS.CTAtuyaColor2]}
            style={tailwind(`w-8 h-8 border-transparent rounded-md border-solid`)}
          >
            { checkIconComponent && <View className="w-full h-full items-center justify-center">{checkIconComponent}</View>}
          </LinearGradient>
        ) : (
          <View className="w-4 h-4 m-2 border-negro-txt-tuya rounded-md opacity-32 border-solid border-2 bg-transparent"/>
        )}
      </TouchableOpacity>
      <Text className={`ml-2 text-negro-txt-tuya ${size === 'big' ? ' text-base ' : 'text-sm'}`}>{label}</Text>
    </View>
  );
};
