import React from "react";
import { View, TextInput, StyleSheet, Text } from "react-native";
import { IconNames, InputTypes } from "../../../shared/types-interfaces";
import { generateIconComponent } from "../../../shared/services";
import stylesSCSS from '../../../styles/style.module.scss';
interface TuyaInputProps {
  /**
   * How large should the be?
   */
  size?: "small" |  "big";
  /**
   * placeholder
   */
  placeholder: string;
  /**
   * disable
   */
  disabled?: boolean;
  /** Error description of the input */
  error?: boolean;
  /** Error Message */
  errMsg?: string;
  /** The type of input */
  type: InputTypes;
  value?: string;
  /**
   * Optional icon inside right name
   */
   iconInsideRightName?: IconNames;

  /**
   * Optional icon outside left name
   */
   iconOutsideLeftName?: IconNames;
  /**
   * click handler
   */
  onClick?: () => void;
  /**
   * change handler
   */
  onChange?: (text: any) => void;
}
export const TuyaInput: React.FC<TuyaInputProps> = ({
  size = "small",
  placeholder = "tuya placeholder",
  disabled = false,
  type = "default",
  error = false,
  errMsg = '',
  ...props
}: TuyaInputProps) => {

  let [currentValue, onChangeText] = React.useState(props.value);
  if(currentValue !== props.value){
    onChangeText(props.value)
  }

  const styles = StyleSheet.create({
    tuyaInputSmall: {
      paddingLeft: '16px',
      height: '56px',
      width: '308px',
    },
    tuyaInputBig: {
      paddingLeft: '16px',
      height: '60px',
      width: '308px',
    },
  });
  
  const getSize = () => size === 'small' ? styles.tuyaInputSmall : styles.tuyaInputBig;

  let iconOutsideLeftComponent = generateIconComponent(props.iconOutsideLeftName);
  if(iconOutsideLeftComponent) {
    styles.tuyaInputBig = {...styles.tuyaInputBig, width: "280px"}
    styles.tuyaInputSmall = {...styles.tuyaInputSmall, width: "280px"}
  }

  let iconInsideRightComponent = generateIconComponent(props.iconInsideRightName);
  if(iconInsideRightComponent) {
    styles.tuyaInputBig = {...styles.tuyaInputBig, width: "382px"}
    styles.tuyaInputSmall = {...styles.tuyaInputSmall, width: "382px"}
  }
  
  return (
    <>  
      <View className="flex flex-row items-center">
        {props.iconOutsideLeftName && iconOutsideLeftComponent && <View className="pr-2">{iconOutsideLeftComponent}</View>}
        <View className={
          `${
            disabled ? "opacity-50" : "opacity-100"
          }`}>
          <View style={[getSize()]}
            className={`bg-material-tuya rounded-2xl outline-none shadow-inset-tuya ${error ? 'border-error-tuya border': ''} flex flex-row items-center`}
          > 
            <View className={`${props.iconInsideRightName ? 'w-90/100': 'w-full'} h-full`}>
              {currentValue && <Text className={`text-negro-txt-tuya opacity-32 text-xs ${size === 'big' ? 'mt-2.75' : 'mt-2.25'}`}>
                  {placeholder}
                </Text>}
              <TextInput
                className={`outline-none text-negro-txt-tuya border-transparent mx-0 text-base ${!currentValue ? 'my-auto': 'my-0'}`}
                underlineColorAndroid="transparent"
                placeholder={placeholder}
                placeholderTextColor={stylesSCSS.negroTxtTuya}
                editable={!disabled}
                keyboardType={type}
                value={currentValue}
                onChangeText={(text) => {
                  props.onChange && props.onChange(text);
                  onChangeText(text)
                }}
              />
            </View>

            {props.iconInsideRightName && iconInsideRightComponent && <View className="pr-2">{iconInsideRightComponent}</View>}
          </View>
        </View>
      </View>
      {error && <Text className="absolute text-error-tuya pl-4 tracking-normal text-sm">{errMsg}</Text>}
    </>
  );
};
