import React from "react";
import { View, TouchableOpacity, Text, StyleSheet } from "react-native";
import tailwind from "tailwind-rn";
import LinearGradient from "react-native-web-linear-gradient";
import stylesSCSS from '../../../styles/style.module.scss';

interface TuyaRadioButtonProps {
  /**
   * Button contents
   */
  label: string;

  selected: boolean;
  /**
   * Button disable
   */
  disabled?: boolean;
  /**
   * How large should the button be?
   */
  size?: "default" | "big";
  onClick?: (currentSelected: boolean) => void;
}

export const TuyaRadioButton: React.FC<TuyaRadioButtonProps> = ({
  label,
  size = "default",
  selected = false,
  disabled = false,
  ...props
}: TuyaRadioButtonProps) => {
  const styles = StyleSheet.create({
    container: {
      height: 32,
      width: 145,
    },
  });

  return (
    <View style={styles.container} className={`flex flex-row items-center m-0 p-0 ${disabled ? " cursor-not-allowed opacity-50" : "opacity-100"}`}>
      <TouchableOpacity
        className="shadow-inset-tuya w-8 h-8 rounded-full border-2 bg-transparent border-transparent items-center justify-center"
        onPress={() => {
          props.onClick && props.onClick(!selected)
        }}
        disabled={disabled}
      >
        {selected ? (
          <LinearGradient
            colors={[stylesSCSS.CTAtuyaColor1,stylesSCSS.CTAtuyaColor2]}
            style={tailwind(`w-5 h-5 border-transparent rounded-full border-solid`)}
          ></LinearGradient>
        ) : (
          <View className="w-4 h-4 m-2 border-negro-txt-tuya rounded-full opacity-52 border-solid border-2 bg-transparent" />
        )}
      </TouchableOpacity>
      <Text className={`ml-2 text-negro-txt-tuya ${size === 'big' ? ' text-base ' : 'text-sm'}`}>{label}</Text>
    </View>
  );
};
